@@ -26,6 +26,7 @@ from prometheus_client import \
     CollectorRegistry, Counter, Gauge, Summary, \
     push_to_gateway, write_to_textfile, start_http_server, exposition
 import redis
+from redis import asyncio as aioredis
 
 
 @singleton
@@ -171,7 +172,8 @@ services = {
     "aiostorage_resource": {},
     "storage_client": {},
     "storage_resource": {},
-    "redis_client": {}
+    "redis_client": {},
+    "aioredis_client": {}
 }
 
 
@@ -523,3 +525,15 @@ class Factory:
         kwargs["port"] = cnfg["port"] if not "port" in kwargs else kwargs["port"]
         kwargs["db"] = cnfg["db"] if not "db" in kwargs else kwargs["db"]
         return self.get_instance(redis.Redis, service_name, instance_name, [], kwargs)
+
+    def aioredis_client(self, **kwargs):
+        service_name = "aioredis_client"
+        instance_name = self.def_instance_name if not self.key_istance_name in kwargs else kwargs[self.key_istance_name]
+        scrts = self.secrets["redis"]
+        cnfg = self.config["redis"]
+        kwargs["host"] = cnfg["url"] if not "url" in kwargs else kwargs["url"]
+        kwargs["password"] = scrts["password"] if not "password" in kwargs else kwargs["password"]
+        kwargs["port"] = cnfg["port"] if not "port" in kwargs else kwargs["port"]
+        kwargs["db"] = cnfg["db"] if not "db" in kwargs else kwargs["db"]
+        return self.get_instance(aioredis.Redis, service_name, instance_name, [], kwargs)
+
